---
name: Other
about: 'Report some other kind of a problem'
title: ''
labels: triage
assignees: ''

---

#### Software information (if applicable)
Please, provide information about your software:
- Operating System:
- python==
- delu==
- numpy==
- torch==
- pynvml==
- tqdm==

#### Describe the issue
